@@ -1,8 +1,8 @@
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 
 from ._reader import napari_get_reader
-from ._writer import napari_get_writer, napari_write_image
+from ._writer import napari_write_image
 from ._dock_widget import napari_experimental_provide_dock_widget
 
