@@ -1,5 +1,7 @@
 import numpy as np
 from napari_mrcfile_handler import napari_get_reader
+import mrcfile
+
 
 
 # tmp_path is a pytest fixture
@@ -8,8 +10,8 @@ def test_reader(tmp_path):
 
     # write some fake data using your supported file format
     my_test_file = str(tmp_path / "myfile.npy")
-    original_data = np.random.rand(20, 20)
-    np.save(my_test_file, original_data)
+    original_data = np.random.rand(20, 20).astype(np.float32)
+    mrcfile.new(my_test_file, original_data)
 
     # try to read it back in
     reader = napari_get_reader(my_test_file)
